nsim.models package
===================

Submodules
----------

nsim.models.basic_sde module
----------------------------

.. automodule:: nsim.models.basic_sde
    :members:
    :undoc-members:
    :show-inheritance:

nsim.models.neural_mass module
------------------------------

.. automodule:: nsim.models.neural_mass
    :members:
    :undoc-members:
    :show-inheritance:

nsim.models.oscillators module
------------------------------

.. automodule:: nsim.models.oscillators
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: nsim.models
    :members:
    :undoc-members:
    :show-inheritance:
